@@ -21,7 +21,7 @@
 #  @allmethods "public"
 # }
 # 
-# @author
+# @author "HB"
 #
 # \seealso{
 #   @see "PairedPSCBS".
@@ -51,7 +51,7 @@ setMethodS3("getSegmentTrackPrefixes", "PSCBS", function(fit, ...) {
 }, protected=TRUE)
 
 
-setMethodS3("getLocusData", "PSCBS", function(fit, indices=NULL, fields=c("asis", "full"), ...) {
+setMethodS3("getLocusData", "PSCBS", function(fit, indices=NULL, fields=c("asis"), ...) {
   # Argument 'indices':
   if (!is.null(indices)) {
     indices <- Arguments$getIndices(indices);
@@ -60,7 +60,6 @@ setMethodS3("getLocusData", "PSCBS", function(fit, indices=NULL, fields=c("asis"
   # Argument 'fields':
   fields <- match.arg(fields);
 
-
   data <- fit$data;
 
   # Return requested indices
@@ -75,41 +74,11 @@ setMethodS3("getLocusData", "PSCBS", function(fit, indices=NULL, fields=c("asis"
     stopifnot(nrow(data) == length(indices));
   }
 
-  if (fields == "full") {
-    names <- colnames(data);
-
-    # Genotype calls
-    if (!is.element("muN", names)) {
-      require("aroma.light") || throw("Package not loaded: aroma.light");
-      data$muN <- callNaiveGenotypes(data$betaN);
-    }
-    data$isHet <- (data$muN == 1/2);
-
-    data$rho <- 2*abs(data$betaT-1/2);
-    data$c1 <- 1/2*(1-data$rho)*data$CT;
-    data$c2 <- data$CT - data$c1;
-
-    # TumorBoost BAFs
-    if (!is.element("betaTN", names)) {
-      require("aroma.light") || throw("Package not loaded: aroma.light");
-      data$betaTN <- normalizeTumorBoost(betaN=data$betaN, betaT=data$betaT, muN=data$muN);
-    }
-    data$rhoN <- 2*abs(data$betaTN-1/2);
-    data$c1N <- 1/2*(1-data$rhoN)*data$CT;
-    data$c2N <- data$CT - data$c1N;
-
-    data$isSNP <- (!is.na(data$betaT) | !is.na(data$betaN));
-    data$type <- ifelse(data$isSNP, "SNP", "non-polymorphic locus");
-
-    # Labels
-    data$muNx <- c("AA", "AB", "BB")[2*data$muN + 1L];
-    data$isHetx <- c("AA|BB", "AB")[data$isHet + 1L];
-  }
-
   data;
 }, protected=TRUE) # getLocusData()
 
 
+
 setMethodS3("isSegmentSplitter", "PSCBS", function(fit, ...) {
   segs <- fit$output;
 
@@ -142,7 +111,7 @@ setMethodS3("isSegmentSplitter", "PSCBS", function(fit, ...) {
 #   and K is the number of segment-specific fields.
 # }
 #
-# @author
+# @author "HB"
 #
 # \seealso{
 #   @seeclass
