@@ -50,8 +50,10 @@ setMethodS3("getLocusData", "PairedPSCBS", function(fit, ..., fields=c("asis", "
 
     # Genotype calls
     if (!is.element("muN", names)) {
-      require("aroma.light") || throw("Package not loaded: aroma.light");
-      data$muN <- callNaiveGenotypes(data$betaN);
+      if (packageVersion("aroma.light") < "1.31.5") {
+        require("aroma.light") || throw("Package not loaded: aroma.light");
+      }
+      data$muN <- aroma.light::callNaiveGenotypes(data$betaN);
     }
     data$isHet <- (data$muN == 1/2);
 
@@ -61,8 +63,13 @@ setMethodS3("getLocusData", "PairedPSCBS", function(fit, ..., fields=c("asis", "
 
     # TumorBoost BAFs
     if (!is.element("betaTN", names)) {
-      require("aroma.light") || throw("Package not loaded: aroma.light");
-      data$betaTN <- normalizeTumorBoost(betaN=data$betaN, betaT=data$betaT, muN=data$muN);
+      # Workaround for older versions of aroma.light::normalizeTumorBoost()
+      # assuming that the R.utils package is attached. /HB 2013-09-20
+      if (packageVersion("aroma.light") < "1.31.5") {
+        pkg <- "R.utils";
+        require(pkg, character.only=TRUE) || throw("Package not loaded: ", pkg);
+      }
+      data$betaTN <- aroma.light::normalizeTumorBoost(betaN=data$betaN, betaT=data$betaT, muN=data$muN);
     }
     data$rhoN <- 2*abs(data$betaTN-1/2);
     data$c1N <- 1/2*(1-data$rhoN)*data$CT;
